clear,clc;
close all;
cc=gray(12);
load('methane_data.mat');
load('xenon_data.mat');

L=115; % domain height
x_vec=linspace(0,L,257);
t_vec=0:0.5:40;

for index=[1:4 11]
figure(1);subplot(121);hold on;
plot(ch4_chi(8*(index-1)+1,:),x_vec,'linewidth',3,'color',cc(index,:));
t_vec(8*(index-1)+1)
end
xlabel('CH_4 mole fraction');
ylabel('depth z [\mum]');
set(gca,'fontsize',14);

for index=[1:4 11]
figure(1);subplot(122); hold on;
plot(xe_chi(8*(index-1)+1,:),x_vec,'linewidth',3,'color',cc(index,:));
end

figure(1);subplot(122);
legend('t=0min','t=4min','t=8min','t=12min','t=40min');
xlabel('Xe mole fraction');

figure(1);set(gca,'fontsize',14);

%% final composition profile for Methane
figure(3);subplot(221); 
plot(ch4_Sg(1,:),x_vec,'--','linewidth',3,'color',192.*ones(1,3)./256);
hold on;
plot(ch4_Sg(81,:),x_vec,'color',[0 191 255]./256,'linewidth',3);
plot(ch4_chi(81,:),x_vec,'r','linewidth',3);
plot(ch4_Sh(81,:),x_vec,'k','linewidth',3);
axis([-0.01 1.01 0 L]);
xlabel('CH_4 mole fraction');
ylabel('depth z [\mum]');
set(gca,'fontsize',14);


figure(3); subplot(222); 
plot(ch4_Sg(1,:),x_vec,'--','linewidth',3,'color',192.*ones(1,3)./256);
hold on;
plot(ch4_Sg(81,:),x_vec,'color',[0 191 255]./256,'linewidth',3);
plot(ch4_chi(81,:),x_vec,'r','linewidth',3);
plot(ch4_Sh(81,:),x_vec,'k','linewidth',3);
xlabel('CH_4 mole fraction');
ylabel('depth z [\mum]');
legend('initial gas saturation profile','t=40 min  gas saturation profile','hydrate saturation profile','profile of methane mole fraction');
axis([0.11 0.16 10 90]);
set(gca,'fontsize',14);

%% final composition profile for Xenon
figure(3);subplot(223); 
plot(xe_Sg(1,:),x_vec,'--','linewidth',3,'color',192.*ones(1,3)./256);
hold on;
plot(xe_Sg(81,:),x_vec,'color',[0 191 255]./256,'linewidth',3);
plot(xe_chi(81,:),x_vec,'r','linewidth',3);
plot(xe_Sh(81,:),x_vec,'k','linewidth',3);
axis([-0.01 1.01 0 L]);
xlabel('Xe mole fraction');
ylabel('depth z [\mum]');
set(gca,'fontsize',14);


figure(3); subplot(224); 
plot(xe_Sg(1,:),x_vec,'--','linewidth',3,'color',192.*ones(1,3)./256);
hold on;
plot(xe_Sg(81,:),x_vec,'color',[0 191 255]./256,'linewidth',3);
plot(xe_chi(81,:),x_vec,'r','linewidth',3);
plot(xe_Sh(81,:),x_vec,'k','linewidth',3);
xlabel('Xe mole fraction');
ylabel('depth z [\mum]');
legend('initial gas saturation profile','t=40 min  gas saturation profile','hydrate saturation profile','profile of methane mole fraction');
axis([0.11 0.16 10 90]);
set(gca,'fontsize',14);

%% hydrate film thickness

% data from Taylor et al. 2007
% 7.5C subcooling
data75=[0.047779058052762835, 6.045016077170416;
0.7134282077423801, 12.9903536977492;
8.496166213208012, 42.05787781350483;
17.094496359259907, 51.51125401929261;  
35.27488040153713, 51.31832797427653];

% 5.2C subcooling
data52=[0.15519144803122487, 9.71061093247588;
0.9383879394074679, 13.118971061093248;
3.1254562236445995, 18.842443729903536;
7.159167003492941, 32.218649517684895;
36.6519669648836, 32.66881028938907];

% 3.5C subcooling
data35=[0.06759650826782782, 8.038585209003223;
1.506126216345022, 9.646302250803863;
2.6807852174490083, 14.855305466237944;
4.5914950863582344, 16.9774919614148;
12.582633036322944, 17.942122186495176;
25.9779625127441, 18.327974276527335];

% simulation data
ch4_Sh_avg=sum(ch4_Sh,2)./257*L;
xe_Sh_avg=sum(xe_Sh,2)./257*L;

% plotting
figure(2);hold on;
plot(t_vec-1.5,ch4_Sh_avg,'r','linewidth',2);
plot(data75(:,1),data75(:,2),'ko','markersize',10,'markerfacecolor','k');
plot(t_vec-1,xe_Sh_avg,'r--','linewidth',2);
xlabel('time [min]');ylabel('hydrate film thickness [\mum]');
legend('CH_{4} simulation','CH_{4} data from Taylor et al. 2007','Xe simulation');
axis([0 40 0 70]);
set(gca,'fontsize',14);
